@@ -1,7 +1,7 @@
 package Graph::Weighted;
 use strict;
 use Carp;
-use vars qw($VERSION); $VERSION = '0.05.1';
+use vars qw($VERSION); $VERSION = '0.08.1';
 use base qw(Graph::Directed);
 
 use constant WEIGHT => 'weight';
@@ -139,6 +139,8 @@ $self->_debug('exiting graph_weight');
 sub vertex_weight {  # {{{
     my ($self, $vertex, $weight) = @_;
 $self->_debug("entering vertex_weight with $vertex");
+    croak "Can't compute the weight of an undefined vertex."
+        unless defined $vertex;
 
     if (defined $weight) {
         # Distribute the weight to all outgoing edges.
@@ -184,6 +186,8 @@ $self->_debug('exiting vertex_weight');
 sub edge_weight {  # {{{
     my ($self, $vertex, $successor, $weight) = @_;
 $self->_debug("entering edge_weight with $vertex and $successor");
+    croak "Can't compute the weight of an edge bounded by undefined vertices."
+        unless defined $vertex && defined $successor;
 
     if (defined $weight) {
 $self->_debug("weight is defined as $weight");
@@ -225,6 +229,8 @@ sub heaviest_vertices {  # {{{
 $self->_debug('entering heaviest_vertices');
 
     unless (defined $self->{heaviest_vertices}) {
+        $self->{heaviest_vertices} = [];
+
         my $heavy = 0;
 
         for ($self->vertices) {
@@ -250,6 +256,8 @@ sub lightest_vertices {  # {{{
 $self->_debug('entering lightest_vertices');
 
     unless (defined $self->{lightest_vertices}) {
+        $self->{lightest_vertices} = [];
+
         my $light;
 
         for ($self->vertices) {
@@ -330,8 +338,8 @@ Graph::Weighted - A weighted graph implementation
   $heavies = $g->heaviest_vertices;
   $lights  = $g->lightest_vertices;
 
-  $x = $g->max_weight;  # Equal to the $heavies.
-  $y = $g->min_weight;  # Equal to the $lights.
+  $x = $g->max_weight;  # Equal to the weight of the $heavies.
+  $y = $g->min_weight;  # Equal to the weight of the $lights.
 
   # Call any methods of the inherited Graph module.
   @v = $g->vertices;
@@ -340,10 +348,6 @@ Graph::Weighted - A weighted graph implementation
   $z = $g->APSP_Floyd_Warshall;
   $z = $g->MST_Prim($p);
 
-=head1 ABSTRACT
-
-A weighted graph implementation
-
 =head1 DESCRIPTION
 
 A C<Graph::Weighted> object represents a subclass of 
@@ -404,37 +408,31 @@ Get the total weight of the graph, by summing all the vertex weights.
 
 =item vertex_weight $VERTEX [, $WEIGHT]
 
-Return the weight of a vertex.  This method can also be used to set 
-the vertex weight, if a second argument is provided.
+Return the weight of a vertex.
 
 (The vertices are just the keys of the data, not some glorified 
-object.)
+object, by the way.)
 
-When the second argument is provided, the weight it represents is 
-distributed evenly to the vertex's outgoing edges, and the total 
-weight of the entire graph is adjusted accordingly.
+If a second argument is provided, the vertex weight is set to that 
+value and is distributed evenly to the vertex's outgoing edges, and 
+the total weight of the graph is adjusted accordingly.
 
-=item edge_weight $VERTEX, $NEIGHBOR [, $WEIGHT]
+=item edge_weight $VERTEX, $SUCCESSOR [, $WEIGHT]
 
-Return the weight of an edge between the two given vertices.  This 
-method can also be used to set the edge weight, if a third argument 
-is provided.
+Return the weight of an edge between the two given vertices.
 
-(The vertices are just the keys of the data, not some glorified 
-object.)
-
-When the third argument is provided, the weight it represents is used
+If a third argument is provided, the weight it represents is used
 to replace the weight of the edge between the vertex (first argument)
-and it's successor (second argument).  Lastly, the total weight of the 
-entire graph and the weight of the vertex are adjusted accordingly.
+and it's successor (second argument).  Finally, the weight of the 
+vertex and the total weight of the graph are adjusted accordingly.
 
 =item heaviest_vertices
 
-Return the array reference of vertices with the most weight.
+Return an array reference of vertices with the most weight.
 
 =item lightest_vertices
 
-Return the array reference of vertices with the least weight.
+Return an array reference of vertices with the least weight.
 
 =item max_weight
 
@@ -458,19 +456,15 @@ Print the contents of the argument array with a newline appended.
 
 =head1 SEE ALSO
 
-C<Graph::Base>
+L<Graph::Base>
 
 =head1 TO DO
 
 Handle clusters of vertices and sub-graphs.
 
-Handle "capacity graphs" as detailed in the C<Graph::Base> module?
-
-Handle Math::MatrixSparse and PDL::Matrix objects?
-
 =head1 AUTHOR
 
-Gene Boggs E<lt>gene@cpan@.orgE<gt>
+Gene Boggs E<lt>gene@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
